@@ -1,6 +1,6 @@
 import importlib
 import pkgutil
-from commitizen.cz.cz_conventional_changelog import ConventionalChangelogCz
+from commitizen.cz.cz_conventional_commits import ConventionalCommitsCz
 from commitizen.cz.cz_jira import JiraSmartCz
 
 
@@ -12,6 +12,6 @@ registry = {
 }
 
 registry.update({
-    'cz_conventional_changelog': ConventionalChangelogCz,
+    'cz_conventional_commits': ConventionalCommitsCz,
     'cz_jira': JiraSmartCz
 })
